@@ -1,15 +1,21 @@
-use crate::broker_statement::partial::PartialBrokerStatement;
-use crate::broker_statement::xls::{XlsStatementParser, SectionParser};
+use crate::broker_statement::partial::{PartialBrokerStatement, PartialBrokerStatementRc};
 use crate::core::{EmptyResult, GenericResult};
 use crate::currency::Cash;
 use crate::types::Decimal;
-use crate::xls::{self, TableReader, Cell, SkipCell};
+use crate::xls::{self, XlsStatementParser, SectionParser, TableReader, Cell, SkipCell};
 
 use xls_table_derive::XlsTableRow;
 
 use super::common::{parse_currency, parse_symbol};
 
 pub struct AssetsParser {
+    statement: PartialBrokerStatementRc,
+}
+
+impl AssetsParser {
+    pub fn new(statement: PartialBrokerStatementRc) -> Box<dyn SectionParser> {
+        Box::new(AssetsParser {statement})
+    }
 }
 
 impl SectionParser for AssetsParser {
@@ -19,40 +25,17 @@ impl SectionParser for AssetsParser {
 
     fn parse(&mut self, parser: &mut XlsStatementParser) -> EmptyResult {
         let mut has_starting_assets = false;
+        let mut statement = self.statement.borrow_mut();
 
         for asset in &xls::read_table::<AssetRow>(&mut parser.sheet)? {
             has_starting_assets |= asset.start_value.is_some();
 
             if !asset.name.ends_with(" (в пути)") {
-                self.process_asset(&mut parser.statement, asset)?;
+                asset.parse(&mut statement)?;
             }
         }
 
-        parser.statement.set_has_starting_assets(has_starting_assets)
-    }
-}
-
-impl AssetsParser {
-    fn process_asset(&self, statement: &mut PartialBrokerStatement, asset: &AssetRow) -> EmptyResult {
-        let is_currency = asset.security_type.as_ref()
-            .map(|value| value.trim().len()).unwrap_or(0) == 0;
-
-        if is_currency {
-            if let Some(amount) = asset.end_value {
-                let currency = &parse_currency(&asset.name)?;
-                statement.assets.cash.as_mut().unwrap().deposit(Cash::new(currency, amount))
-            }
-        } else {
-            let quantity = asset.end_quantity.unwrap_or(0);
-            if quantity < 0 {
-                return Err!("Got a negative open position for {:?}", asset.name);
-            } else if quantity != 0 {
-                let symbol = parse_symbol(&asset.name)?;
-                statement.add_open_position(&symbol, quantity.into())?;
-            }
-        }
-
-        Ok(())
+        statement.set_has_starting_assets(has_starting_assets)
     }
 }
 
@@ -92,4 +75,28 @@ impl TableReader for AssetRow {
     fn skip_row(row: &[Option<&Cell>]) -> GenericResult<bool> {
         Ok(xls::get_string_cell(row[0].unwrap())? == "Итого:")
     }
+}
+
+impl AssetRow {
+    fn parse(&self, statement: &mut PartialBrokerStatement) -> EmptyResult {
+        let is_currency = self.security_type.as_ref()
+            .map(|value| value.trim().len()).unwrap_or(0) == 0;
+
+        if is_currency {
+            if let Some(amount) = self.end_value {
+                let currency = &parse_currency(&self.name)?;
+                statement.assets.cash.as_mut().unwrap().deposit(Cash::new(currency, amount))
+            }
+        } else {
+            let quantity = self.end_quantity.unwrap_or(0);
+            if quantity < 0 {
+                return Err!("Got a negative open position for {:?}", self.name);
+            } else if quantity != 0 {
+                let symbol = parse_symbol(&self.name)?;
+                statement.add_open_position(&symbol, quantity.into())?;
+            }
+        }
+
+        Ok(())
+    }
 }
\ No newline at end of file
