@@ -1,15 +1,22 @@
 use lazy_static::lazy_static;
 use regex::Regex;
 
-use crate::broker_statement::xls::{XlsStatementParser, SectionParser};
+use crate::broker_statement::partial::PartialBrokerStatementRc;
 use crate::core::{EmptyResult, GenericResult};
 use crate::time;
 use crate::types::Date;
-use crate::xls;
+use crate::xls::{self, XlsStatementParser, SectionParser};
 
 use super::common::parse_date;
 
 pub struct PeriodParser {
+    statement: PartialBrokerStatementRc,
+}
+
+impl PeriodParser {
+    pub fn new(statement: PartialBrokerStatementRc) -> Box<dyn SectionParser> {
+        Box::new(PeriodParser {statement})
+    }
 }
 
 impl SectionParser for PeriodParser {
@@ -18,7 +25,7 @@ impl SectionParser for PeriodParser {
     fn parse(&mut self, parser: &mut XlsStatementParser) -> EmptyResult {
         let row = xls::strip_row_expecting_columns(parser.sheet.next_row_checked()?, 2)?;
         let period = parse_period(xls::get_string_cell(row[1])?)?;
-        parser.statement.set_period(period)?;
+        self.statement.borrow_mut().set_period(period)?;
         Ok(())
     }
 }
